.. _api_geometry_ellipse:

.. currentmodule:: microstructpy.geometry

microstructpy.geometry.Ellipse
==============================

.. autoclass:: Ellipse
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: